""" Handles the printing of the feeds

Functions:
    set_verbose_print(logging_level): set the configuration for loggings
    wrap_text(text): makes sure the line lengths are no more than 120 for the input
    print_json_format(dictionary): Prints the content of the feeds dictionary in json format
    print_regular_format(dic_temp): Prints the content of the feeds dictionary in regular format

"""
import logging
import textwrap

def set_verbose_print(logging_level):
    """ set the configuration for loggings

    Args:
        logging_level (str): the level of loggings user is willing to be shown

    Retruns:
        None
    """
    logging.basicConfig(format='%(levelname)s:%(message)s', level=logging_level)

def wrap_text(text):
    """ makes sure the line lengths are no more than 120 for the input


    Args:
        text (str): text to be formated in the lines of length 120

    Retruns:
        (str): formatted text
    """
    return '\n'.join(textwrap.wrap(text, 120))


def print_json_format(dictionary):
    """ Prints the content of the feeds dictionary in json format

    Args:
    dictionary: a dictionary of RSS items including title, date, news content...

    Retruns:
    None
    """

    # Approach number 1
    # manually prining the feeds dictionary in json format
    logging.info("Printing the feed in json\n")
    print("{")
    for item in dictionary.keys():
        print(f'\n\t"{item}": {{')
        for item_item in dictionary[item].keys():
            if (item_item == "content"):
                content = '\n\t\t           '.join(textwrap.wrap(dictionary[item].get(item_item), 64))
                print(f'\t\t"{item_item}": "{content}"')
            elif (item_item == "image link"):
                img_link = '\n\t\t              '.join(textwrap.wrap(dictionary[item].get(item_item), 64))
                print(f'\t\t"{item_item}": "{img_link}"')
            elif (item_item == "link"):
                link = '\n\t\t        '.join(textwrap.wrap(dictionary[item].get(item_item), 64))
                print(f'\t\t"{item_item}": "{link}"')
            else:
                print(f'\t\t"{item_item}": "{dictionary[item].get(item_item)}"')

        print("\t},")
    print("}")

    # Approach number 2

    # out_file = open("test2.json", "w")
    # json.dump(json_dit, out_file, indent=4)
    # out_file.close()

    # myfile = open("test2.json")
    # txt = myfile.read()
    # print(txt)
    # myfile.close()

    # import os
    # os.remove("test2.json")


run_once = 0
def print_regular_format(dic_temp):
    """ Prints the content of the feeds dictionary in regular format

    Args:
    dictionary: a dictionary of RSS items including title, date, news content...

    Retruns:
    None
    """
    global run_once
    if run_once == 0:
        logging.info("Printing the RSS feed")
        run_once += 1


    print("------------------------------------------------------------------------------------")
    print(f"Title: {wrap_text(dic_temp.get('title'))}")
    print(f"Date: {wrap_text(dic_temp.get('date'))}")
    print(f"Link: {wrap_text(dic_temp.get('link'))}\n")
    print(f"[image: {wrap_text(dic_temp.get('title'))}][2]\n{wrap_text(dic_temp.get('content'))}[1]\n\n")
    print(f"[1]: {wrap_text(dic_temp.get('link'))} (link)")

    if dic_temp.get('image link') is not None:
        print(f"[2]: {wrap_text(dic_temp.get('image link'))} (image)\n\n")



""" Handles the parsing and printing the feed of RSS URL

This module provided the RSS URL, reads it and parses its content
and prints the news feed. The option of printing the feed in the
json format is also implemented.

Attributes:
    verision (int): version of the current release

Functions:
    get_encoding(soup): Checks the encoding of the html file of
                        the news page
"""
# import argparse
# from prepare_data import show_feeds, set_verbose_prep
# from print_news import set_verbose_print
# import logging
# from cache_news import show_chache_bydate, set_verbose_cache

import argparse
from prepare_data import show_feeds, set_verbose_prep
from print_news import set_verbose_print
import logging
from cache_news import show_chache_bydate, set_verbose_cache, clear_cache, retrieve_by_number
from RSSItems import RSSItems
from convert_format import convert_html

# try:
#     import argparse
#     from prepare_data import show_feeds, set_verbose_prep
#     from print_news import set_verbose_print
#     import logging
#     from cache_news import show_chache_bydate, set_verbose_cache, clear_cache, retrieve_by_number
#     from RSSItems import RSSItems
#     from convert_format import convert_html
# except ImportError:
#     raise SystemExit('Error: Modules missing!')

# version of the current release
def main():
    version = 1.0

    parser = argparse.ArgumentParser(description="Pure Python command-line RSS reader.")
    parser.add_argument("--version", action="store_true", help="Print version info")
    parser.add_argument("--json", action="store_true", help="Print result as JSON in stdout")
    parser.add_argument("--verbose", action="store_true", help="Outputs verbose status messages")
    parser.add_argument("--limit", help="Limit news topics if this parameter provided", type=int)
    parser.add_argument("source", default="empty", nargs='?', help="RSS URL")
    parser.add_argument("--date", help="Show cached news published after date")
    parser.add_argument("--clear",action="store_true", help="Clears cache.")
    parser.add_argument("--to-html", help="Converts and stores in HTML at the user-provided path.")
    parser.add_argument("--to-pdf", help="Converts and stores in PDF at the user-provided path.")
    args = parser.parse_args()




    # cheking in the verbose flag is set to TRUE
    if(args.verbose):
        logging_level = logging.INFO
        logging.basicConfig(format='%(levelname)s:%(message)s', level=logging.INFO)
        logging.info("Verbose is set to ON!")
    else:
        # if the verbose flag is not set, then no logging message
        # should be printed, setting the logging level to one more
        # than the highest level will do the job
        logging_level = logging.CRITICAL + 1

    # based on the set/unset verbose flag, set the logging level for other
    # moodles too
    logging.basicConfig(format='%(levelname)s:%(message)s', level=logging_level)
    set_verbose_prep(logging_level)
    set_verbose_print(logging_level)
    set_verbose_cache(logging_level)

    # additional feature
    if (args.clear):
        clear_cache()

    # if the version flag is set, print the version and exit the program
    if(args.version):
        print(f"version: {version}")
        logging.info("Version printed, exiting the program.")
        # if the version flag is set, the only required performance of
        # the app is to show the version and exit, hence:
        exit()

    # if the date option is provided with an argument, only the
    # cached news will be shown
    if(args.date is not None):
        logging.info("Date is set!")
        if(args.to_html is not None):
            html = True
            show_chache_bydate(args.date, args.json, args.limit, args.to_html, html)
        else:
            html = False
            show_chache_bydate(args.date, args.json, args.limit, args.to_pdf, html)

        exit()

    # if the RSS URL is provided by the user, following must be done
    if(args.source != "empty"):
        RSS = RSSItems(args.source, args.json, args.limit)
        if(args.to_html is not None):
            convert_html(RSS.cache_list, args.to_html)
        if (args.to_pdf is not None):
            convert_html(RSS.cache_list, args.to_pdf)
        logging.info("program finished successfully")

    if(args.to_html is None and args.date):
        convert_html(retrieve_by_number(args.limit), args.to_html)




if __name__ == "__main__":
    main()


""" Prepare the data of the news to be printed as the RSS feeds

This modules fetches the XML content of the URL provided by the user,
parses it into XML tree elements, extracts the required data from
this tree structre and prints it in the rquired format provided
by the user



Functions:
    set_verbose_prep(logging_level): set the configuration for loggings
    get_encoding(soup): Checks the encoding of the html file of the news page
    get_content(news_link): Extracts the content summary of the news page
    extract_XML(URL): Given the RSS url, fetches the XML content
    parse_XML(): Parses the XML file
    print_RSS_title(root): Prints the title of the RSS file before the feed
    feeds_number(args_limit, length): Determines number of feeds to be printed
    make_news_dictionary(items, json, root, limit): Parses the XML element tree into a dictionary of feeds
    show_feeds(URL, json, limit): Handles the getching, parsing the XML content and printing the feed
"""
# import xml.etree.ElementTree as ET
# import requests
# import json
# import logging
# from bs4 import BeautifulSoup
# import re
# from datetime import datetime
# from date_time import date_print_format
# from print_news import print_regular_format, print_json_format
# from cache_news import cache_news

import os
try:
    import xml.etree.ElementTree as ET
    import requests
    import json
    import logging
    from bs4 import BeautifulSoup
    import re
    from datetime import datetime
    import os
except ImportError:
    raise SystemExit('Error: Modules missing!')

json_dit = {}
chache_list = []


def set_verbose_prep(logging_level):
    """ set the configuration for loggings

    Args:
        logging_level (str): the level of loggings user is willing to be shown

    Retruns:
        None
    """
    logging.basicConfig(format='%(levelname)s:%(message)s', level=logging_level)


def get_encoding(soup):
    """ Checks the encoding of the html file of the news page

    Args:
        soup (beautifulsoup object): html parsed object with BeautifulSoup
                                     function of bs4 library

    Retruns:
        encod (str): the encoding extracted from the html
    """
    # getting the enocing from the soup object (html parsed object)
    if soup and soup.meta:
        encod = soup.meta.get('charset')
        if encod is None:
            encod = soup.meta.get('content-type')
            if encod is None:
                content = soup.meta.get('content')
                match = re.search('charset=(.*)', content)
                if match:
                    encod = match.group(1)
                else:
                    raise ValueError('unable to find encoding')
    else:
        raise ValueError('unable to find encoding')
    return encod


def get_content(news_link):
    """ Extracts the content summary of the news page

    Args:
        news_link (str): URL of the news page

    Retruns:
        content.attrs.get("content") (str): the summary of the content
                                            of the news page
    """

    try:
        logging.info("Getting the content of the news feed.")
        page = requests.get(news_link)
        text = page.content
        # parsing the content of the webpage into
        # html string
        soup = BeautifulSoup(text, "html.parser")
        # parsing the content of the webpage, this time with the
        # recognized encoding
        soup = BeautifulSoup(text, "html.parser", from_encoding=get_encoding(soup))
        content = soup.find("meta", attrs={"name": "description"})
        return content.attrs.get("content")

    except ValueError:
        # if the get_encoding function is unable to provide
        # correct encoding, continue with the defaults of
        # BeautifulSoup function
        logging.warning("The encoding might not be correct!")
        page = requests.get(news_link)
        text = page.content
        soup = BeautifulSoup(text, "html.parser")
        content = soup.find("meta", attrs={"name": "description"})
        return content.attrs.get("content")


# def extract_XML(URL):
#     """Given the RSS url, fetches the XML content
#
#     The content is then stored in a file names rss.xml
#
#     Args:
#         URL (str): RSS URL provided by the user
#
#     Retruns:
#         None
#     """
#     try:
#         logging.info("Requesting the URL webpage")
#         response = requests.get(URL)
#     except requests.exceptions.RequestException:
#         logging.error("Fetching was unsuccessful.")
#         raise SystemExit("Error: Please insert the RSS URL again or Check internet connectivity.")
#     else:
#         logging.info("Webpage retrieved successfully!")
#
#     xml = os.path.abspath(os.path.join(os.path.dirname(__file__), 'rss.xml'))
#     with open(xml, 'wb') as file:
#         file.write(response.content)


def parse_XML():
    """Parses the xml file

    Reads the rss.xml file and parses it into XML elements in tree structure

    Args:
        None
    Retruns:
        root: root node of the XML tree
        items: feed nodes of the XML tree
    """

    # Parses the XML into element tree
    # and extracts the root of the tree
    try:
        xml = os.path.abspath(os.path.join(os.path.dirname(__file__), 'rss.xml'))
        tree = ET.parse(xml)
    except ET.ParseError:
        logging.error("Parsing was unsuccessful.")
        raise SystemExit("Error: Please insert the RSS URL again.")
    else:
        logging.info("RSS file Parsed successfully!")

    root = tree.getroot()

    # creating a list of all items(titles) in the RSS file
    # in the RSS file, the titles are wrapped in elements
    # with the tag: item
    try:
        items = root.find("channel").findall("item")
    except AttributeError:
        logging.debug("Couldn't find channel tag!")
        logging.error("RSS info is not in proper shape!")
        raise SystemExit("Error: Please insert the RSS URL again.")
    return root, items


def print_RSS_title(root):
    """Prints the title of the RSS file before the feed

    Args:
        root: root of the parsed XML tree

    Retruns:
        None
    """
    # The feed title
    try:
        feed = root.find("channel").find("title").text
        print(feed)
    except AttributeError:
        logging.debug("Couldn't find channel tag!")
        logging.error("RSS  info is not in proper shape!")
        raise SystemExit("Error: Please insert the RSS URL again.")


def feeds_number(args_limit, length):
    """Determines number of feeds to be printed

    Based on the limit input by the user, this number is calculated

    Args:
        args_limit (int): the number limit input by the user

    Retruns:
        limit: number of feeds to be printed
    """
    # limit variable: if the user does not provide a value for it
    # or the value is larger than feed size then user gets all available news feeds
    if args_limit is None:
        limit = length
    else:
        limit = min(length, args_limit)
    return limit


def make_news_dictionary(items, json, root, limit):
    """ Parses the XML element tree into a dictionary of feeds

    Takes the XML element tree and extract from it the required elements
    and stores the items for each feed in a dictionary and then all the feed
    dictionaries into one final dictionary.
    Also caching the read news is called from this function.

    Args:
        items: feed nodes of the XML tree
        json: printing mode specified by the user
        root: root node of the XML tree
        limit: number of cached news specified by the user to be shown

    Retruns:
        None
    """
    # iterator to traverse the news items
    element_iterator = iter(items)

    # run_once variable is for logging the info that the feed is
    # being printed
    # the iteration is performed equal to the limit that is assigned above
    run_once = 0
    news_id = 0
    for count in range(limit):

        # for each news item, title, publication date, news link and
        # image link(if exists) and content is extracted
        element = next(element_iterator)

        # for each news item, extracting info and save them in a temporary dictionary to add then
        # to the feeds dictionary
        try:
            news_URL = element.find("link").text

            try:
                date = element.find("pubDate").text
                date = date_print_format(date)
            except ValueError:
                date = element.find("pubDate").text

            dic_temp = {"title": element.find("title").text, "date": date,
                        "link": news_URL, "content": get_content(news_URL)}
        except AttributeError:
            logging.debug("Tag names were not found!")
            logging.error("RSS  info is not in proper shape!")
            raise SystemExit("Error: Please insert the RSS URL again.")
        except requests.exceptions.RequestException:
            logging.error("Fetching was unsuccessful. Content of the feed is not printed for this news.")

        # assuming initially that an image is available for each item, and fetching its link
        try:
            dic_temp["image link"] = element.find('{http://search.yahoo.com/mrss/}content').get("url")
        except AttributeError:
            dic_temp["image link"] = None

        chache_list.append((date, dic_temp))

        if json == False:
            if (run_once == 0):
                print_RSS_title(root)
                run_once += 1
            print_regular_format(dic_temp)
        else:
            news_id += 1
            json_dit["News Number " + str(news_id)] = dic_temp


def show_feeds(URL, json, limit):
    """Handles the getching, parsing the XML content and printing the feed

    Args:
        URL (str): RSS URL provided by the user
        root: root node of the XML tree
        limit: number of cached news specified by the user to be shown

    Retruns:
        date (str): formatted date
    """

    logging.info("retrieving XML file.")
    extract_XML(URL)
    logging.info("parsing XML file")
    root, items = parse_XML()
    limit = feeds_number(limit, len(items))
    logging.info("Extracting feed information.")
    make_news_dictionary(items, json, root, limit)
    logging.info("caching the news.")
    cache_news(chache_list)
    if json:
        print_RSS_title(root)
        print_json_format(json_dit)
















""" Handles the time and date related operations

Functions:
    date_print_format(date): converts the date string into a particular format
    date_object(date): Given a date in string fomrat, returns a datetime object for date operations
"""

from datetime import datetime
import dateutil.parser


def date_print_format(date):
    """ converts the date string into a particular format

    example timestamp in such format:
    Thu, 21 Apr 2022 09:25:02 +0000

    Args:
        date (str): URL of the news page

    Retruns:
        date (str): formatted date
    """

    format = "%a, %d %b %Y %H:%M:%S %z"
    # RSS files dates are in iso format, to parse them:
    date = dateutil.parser.isoparse(date)
    date = date.strftime(format)
    return date


# def iso_date_format(date):
#     """ converts the date string into a particular format

#     example timestamp in such format:
#     Thu, 21 Apr 2022 09:25:02 +0000

#     Args:
#         date (str): URL of the news page

#     Retruns:
#         date (str): formatted date
#     """
#     format = "%Y%m%d"
#     date = dateutil.parser.isoparse(date)
#     # date = date.strftime(format)
#     # date = datetime.strptime(date, format)
#     date = date.replace(tzinfo= None)
#     return date

def date_object(date):
    """Given a date in string fomrat, returns a datetime object for date operations

    Args:
        date (str): date in string format

    Retruns:
        datetime.strptime(date, "%Y%m%d")(datetime): date object of the given string
    """

    # conver the string into a date object
    return datetime.strptime(date, "%Y%m%d")


import os
from bs4.element import NavigableString
import requests
from bs4 import BeautifulSoup
import shutil
import logging
import json

from prepare_data import get_encoding
def get_soup(news_link):
    """ Extracts the content summary of the news page

    Args:
        news_link (str): URL of the news page

    Retruns:
        content.attrs.get("content") (str): the summary of the content
                                            of the news page
    """

    try:
        page = requests.get(news_link)
        text = page.content
        # parsing the content of the webpage into
        # html string
        soup = BeautifulSoup(text, "html.parser")
        # parsing the content of the webpage, this time with the
        # recognized encoding
        soup = BeautifulSoup(text, "html.parser", from_encoding=get_encoding(soup))
        soup.prettify()
        return soup

    except ValueError:
        # if the get_encoding function is unable to provide
        # correct encoding, continue with the defaults of
        # BeautifulSoup function
        page = requests.get(news_link)
        text = page.content
        soup = BeautifulSoup(text, "html.parser")
        return soup


def extract_XML(URL):
    """Given the RSS url, fetches the XML content

    The content is then stored in a file names rss.xml

    Args:
        URL (str): RSS URL provided by the user

    Retruns:
        None
    """
    try:
        logging.info("Requesting the URL webpage")
        response = requests.get(URL)
    except requests.exceptions.RequestException:
        logging.error("Fetching was unsuccessful.")
        raise SystemExit("Error: Please insert the RSS URL again or Check internet connectivity.")
    else:
        logging.info("Webpage retrieved successfully!")

    xml = os.path.abspath(os.path.join(os.path.dirname( __file__ ), 'rss.xml'))
    with open(xml, 'wb') as file:
        file.write(response.content)

def extract_images(soup):
    images = []
    string_type = NavigableString
    for image in soup.find("article").find_all("img"):
        images.append(image.attrs.get("src"))
    return images


def download_images(soup, feed_cache_directory):
    images_URL_list = extract_images(soup)
    image_id = 0
    images_dir = os.path.abspath(os.path.join(feed_cache_directory, 'images'))
    for url in images_URL_list:
        if (not os.path.isdir(images_dir)):
            os.makedirs(images_dir)
        if(url is not None):
            r = requests.get(url, stream=True)
            if r.status_code == 200:
                image_id += 1
                image_name = "image_" + str(image_id) + ".jpg"
                with open(os.path.abspath(os.path.join(images_dir, image_name)), 'wb') as f:
                    r.raw.decode_content = True
                    shutil.copyfileobj(r.raw, f)


def extract_links(soup, feed_cache_directory):
    links = []
    for item in soup.find("article").find_all("a"):
        link = item.attrs.get("href")
        if(link.startswith("https") or link.startswith("http")):
            links.append(link)

    with open(os.path.abspath(os.path.join(feed_cache_directory, 'links.txt')), 'w') as f:
        f.write(json.dumps(links))




def extract_article(soup):
    article = ""
    string_type = NavigableString
    for paragraph in soup.find("article").find_all("p"):
        if(isinstance(paragraph.next_element, string_type)):
            article = article + "\n" + paragraph.next_element

    return article

def get_news(dic_temp):
    article = extract_article()


import json
import logging
import os

from reportlab.lib.enums import TA_JUSTIFY
from reportlab.lib.pagesizes import letter
from reportlab.platypus import SimpleDocTemplate, Paragraph,Spacer, Image
from reportlab.lib.styles import getSampleStyleSheet, ParagraphStyle
from reportlab.lib.units import inch

# doc = SimpleDocTemplate("celine.pdf",pagesize=letter,
#                         rightMargin=72,leftMargin=72,
#                         topMargin=72,bottomMargin=18)


def get_cached_content_paths(cache_path):
    article_path = None
    links_path = None
    images_paths = []
    items = os.listdir(cache_path)
    for item in items:
        if(item.endswith("images")):
            # for element in os.listdir(os.path.abspath(os.path.join(cache_path,  item))):
            #     images_paths.append(element)
            for image in os.listdir(os.path.abspath(os.path.join(cache_path,  item))):
                images_paths.append(os.path.join(cache_path,'images', image))
            # images_paths.append(os.path.abspath(os.path.join(cache_path,  item)))
        elif(item == "links.txt"):
            links_path = os.path.abspath(os.path.join(cache_path, item))
        else:article_path = os.path.abspath(os.path.join(cache_path, item))
    return article_path, images_paths, links_path


def get_conversion_data(item):
    news = item[1]
    directory = news.get("cache_directory")
    article_path, images_paths, links_path = get_cached_content_paths(directory)
    with open(article_path) as f:
        lines = f.read()
    article = lines
    with open(links_path, 'r') as f:
        links_list = json.loads(f.read())
    title = news.get("title")
    date = news.get("date")
    return title, date, article, images_paths, links_list


# def convert_pdf(cache_list,input_path ):
#     doc = SimpleDocTemplate(input_path, pagesize=letter,
#                             rightMargin=72, leftMargin=72,
#                             topMargin=72, bottomMargin=18)
#
#     styles=getSampleStyleSheet()
#     styles.add(ParagraphStyle(name='Justify', alignment=TA_JUSTIFY))
#     news_id = 0
#     Story = []
#     for item in cache_list:
#         news = item[1]
#         news_id += 1
#         directory = news.get("cache_directory")
#         article_path, images_paths, links_path = get_cached_content_paths(directory)
#         with open(article_path) as f:
#             lines = f.read()
#         article = lines
#         with open(links_path, 'r') as f:
#             links_list = json.loads(f.read())
#         title = news.get("title")
#         date = news.get("date")
#
#         Story.append(Spacer(1, 12))
#         Story.append(Spacer(1, 12))
#         ptext = '<b>News Number:  </b>: %s' % news_id
#         Story.append(Spacer(1, 12))
#         Story.append(Paragraph(ptext, styles["Normal"]))
#         ptext = '<b>Title</b>: %s' % title
#         Story.append(Paragraph(ptext, styles["Normal"]))
#         Story.append(Spacer(1, 12))
#         ptext = '<b>Date</b>: %s' % date
#         Story.append(Paragraph(ptext, styles["Normal"]))
#         Story.append(Spacer(1, 12))
#         ptext = '<b>Article</b>: %s' % article
#         Story.append(Paragraph(ptext, styles["Justify"]))
#         Story.append(Spacer(1, 12))
#
#         for pic in images_paths:
#             im = Image(pic, 2 * inch, 2 * inch)
#             Story.append(im)
#         Story.append(Spacer(1, 12))
#         Story.append(Spacer(1, 12))
#         for link in links_list:
#             ptext = '<a href = %s >Link</a>' % link
#             Story.append(Paragraph(ptext, styles["Normal"]))
#
#     doc.build(Story)

def convert_pdf(cache_list,input_path ):
    doc = SimpleDocTemplate(input_path, pagesize=letter,
                            rightMargin=72, leftMargin=72,
                            topMargin=72, bottomMargin=18)

    styles=getSampleStyleSheet()
    styles.add(ParagraphStyle(name='Justify', alignment=TA_JUSTIFY))
    news_id = 0
    Story = []
    for item in cache_list:
        title, date, article, images_paths, links_list = get_conversion_data(item)
        news_id += 1

        Story.append(Spacer(1, 12))
        Story.append(Spacer(1, 12))
        ptext = '<b>News Number:  </b>: %s' % news_id
        Story.append(Spacer(1, 12))
        Story.append(Paragraph(ptext, styles["Normal"]))
        ptext = '<b>Title</b>: %s' % title
        Story.append(Paragraph(ptext, styles["Normal"]))
        Story.append(Spacer(1, 12))
        ptext = '<b>Date</b>: %s' % date
        Story.append(Paragraph(ptext, styles["Normal"]))
        Story.append(Spacer(1, 12))
        ptext = '<b>Article</b>: %s' % article
        Story.append(Paragraph(ptext, styles["Justify"]))
        Story.append(Spacer(1, 12))

        for pic in images_paths:
            im = Image(pic, 2 * inch, 2 * inch)
            Story.append(im)
        Story.append(Spacer(1, 12))
        Story.append(Spacer(1, 12))
        for link in links_list:
            ptext = '<a href = %s >Link</a>' % link
            Story.append(Paragraph(ptext, styles["Normal"]))

    doc.build(Story)


def convert_html(cache_list, input_path):
    news_id = 0
    body = ""
    for item in cache_list:
        news_id += 1
        title, date, article, images_paths, links_list = get_conversion_data(item)
        text = "<h2>News Number {News_id}</h2><p><b>Title: </b>{Title}<br><b>Date: </b>{Date}<br><b>Article: </b>{Article}<br></p>"
        text = text.format(News_id=news_id, Title=title, Date=date, Article=article)
        for image_path in images_paths:
            text = text + '<img src = {Image_Path} width="200" height="250" style="vertical-align:' \
                          'middle;margin:0px 5px">'.format(Image_Path=image_path)
        n = 0
        for link in links_list:
            n += 1
            text = text + "<p><a href={Link}>link number {N}</a></p>".format(Link = link, N = n)
        body = body + text
    text = '''<html><body>{Text}</body></html>'''.format(Text = body)

    if not input_path.endswith(".html"):
        logging.error("Input path is not ending with .html")
        raise SystemExit('ERROR: Path extension must be .html')

    try:
        file = open(os.path.join(input_path),"w")
        file = open(input_path,"w")
        file.write(text)
        file.close()

    except FileNotFoundError:
        logging.error("Provided path is not correct.")
        raise SystemExit('Path is not correct. Please Input a correct Path.')






from setuptools import setup
from setuptools import find_namespace_packages, find_packages

# Load the README file
with open(file="README.md", mode="r") as readme_handle:
    long_description = readme_handle.read()


setup(
    

    name='rss-parser-celine-trial1',

    author='Celine Hovanessian Far',

    author_email='celien.hovanessian@gmail.com',

    version='4.0.2',

    description='RSS-parser is a command line interface RSS feed reader',

    long_description=long_description,

    long_description_content_type="text/markdown",

    install_requires=[
		"sphinx-rtd-theme",
        "beautifulsoup4==4.11.1",
        "python_dateutil==2.8.2",
        "reportlab==3.6.9",
        "requests==2.27.1"

    ],

    keywords='rss, rss parser, rss feed, news',

    # here are the packages I want "build."
    packages=["RSSparser"],

    include_package_data=True,

    python_requires='>=3.7',

    # py_modules=['source', 'source.rss_version_11'],

    entry_points={
        'console_scripts': [
            'rss_reader=RSSparser.rss_parser:main'
        ]
    },
    

    classifiers=[

        'License :: OSI Approved :: MIT License',

        'Natural Language :: English',

        'Operating System :: OS Independent',

        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.9',

        'Topic :: Education',
    ]
)